import type { ComputedRef, Ref } from 'vue';
import { nextTick, onActivated, onUnmounted, ref, watch } from 'vue';
import type { ChatMessage } from '../model/types';
import emitter from '/@/utils/mitt';
import { debounce } from '/@/utils/util';

export type UseScrollToBottomOption = {
	chatListDom: Ref<HTMLDivElement>;
};

export const useScrollToBottom = (option: UseScrollToBottomOption) => {
	const { chatListDom } = option;

	const scrollToBottom = () => {
		nextTick(() => {
			if (!chatListDom.value) return;
			const parent = chatListDom.value.parentElement;
			if (!parent) return;
			if (parent.scrollHeight > parent.clientHeight) {
				parent.scrollTop = parent.scrollHeight - parent.clientHeight;
			}
		});
	};
	const debounceAmisScroll = debounce(({ instance }) => {
		scrollToBottom();
	}, 500);

	// emitter.on('amis.page.ready', debounceAmisScroll);

	// onUnmounted(() => {
	// 	emitter.off('amis.page.ready');
	// });

	onActivated(() => {
		scrollToBottom();
	});

	return {
		scrollToBottom,
	};
};
